summaryrefslogtreecommitdiffstats
path: root/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
diff options
context:
space:
mode:
authorAndre A. Marin <aamarin@us.ibm.com>2019-03-20 09:01:13 -0500
committerRaja Das <rajadas2@in.ibm.com>2019-07-26 00:54:53 -0500
commita17eb3a5e035368c50323c381020a163aac183d4 (patch)
treeb9922933e6265af083cd2fed541341488414af99 /src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
parent52715d66e492b1401e9a445d295f84e4edee2c41 (diff)
downloadtalos-sbe-a17eb3a5e035368c50323c381020a163aac183d4.tar.gz
talos-sbe-a17eb3a5e035368c50323c381020a163aac183d4.zip
Fix c_str and pos DIMM specialization
Change-Id: I4fa0f8f1650265a091fda7a3a552ed015e137756 Original-Change-Id: Id234f7f14bc4dd90de1f8ea70a4617c513ca1ffa Reviewed-on: http://rchgit01.rchland.ibm.com/gerrit1/74846 Tested-by: FSP CI Jenkins <fsp-CI-jenkins+hostboot@us.ibm.com> Tested-by: Jenkins Server <pfd-jenkins+hostboot@us.ibm.com> Reviewed-by: STEPHEN GLANCY <sglancy@us.ibm.com> Tested-by: Hostboot CI <hostboot-ci+hostboot@us.ibm.com> Tested-by: HWSV CI <hwsv-ci+hostboot@us.ibm.com> Reviewed-by: Mark Pizzutillo <mark.pizzutillo@ibm.com> Reviewed-by: Louis Stermole <stermole@us.ibm.com> Reviewed-by: Jennifer A. Stofer <stofer@us.ibm.com>
Diffstat (limited to 'src/import/generic/memory/lib/utils/shared/mss_generic_consts.H')
-rw-r--r--src/import/generic/memory/lib/utils/shared/mss_generic_consts.H28
1 files changed, 18 insertions, 10 deletions
diff --git a/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H b/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
index 468d2079..25603847 100644
--- a/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
+++ b/src/import/generic/memory/lib/utils/shared/mss_generic_consts.H
@@ -164,7 +164,10 @@ enum generic_ffdc_codes
SET_SI_ODT_WR = 0x1059,
SET_SI_ODT_RD = 0x1060,
SET_SI_GEARDOWN_MODE = 0x1061,
- PRE_DATA_ENGINE_CTOR = 0x1062
+ PRE_DATA_ENGINE_CTOR = 0x1062,
+ SET_DRAM_GEN_METADATA = 0x1063,
+ SET_DIMM_TYPE_METADATA = 0x1064,
+ SET_DIMM_POS_METADATA = 0x1065,
};
///
@@ -343,16 +346,17 @@ enum class throttle_type
};
///
/// @brief Trait classes for proc_type
///
-template< proc_type P >
-class procTraits;
+template< mc_type MC >
+class mcTypeTraits;
///
/// @brief Trait classes for proc_type - NIMBUS specialization
///
template< >
-struct procTraits<proc_type::NIMBUS>
+struct mcTypeTraits<mc_type::NIMBUS>
{
enum
{
@@ -368,15 +372,19 @@ struct procTraits<proc_type::NIMBUS>
};
///
/// @brief Trait classes for proc_type - AXONE specialization
///
-/// TODO: Need to add mc_type
template< >
-struct procTraits<proc_type::AXONE>
+struct mcTypeTraits<mc_type::EXPLORER>
{
enum
{
- EXP_PORTS_PER_OCMB = 1,
+ MC_PER_PROC = 2,
+ MI_PER_MC = 2,
+ MCC_PER_MI = 2,
+ OMI_PER_MCC = 2,
+ OCMB_PER_OMI = 1,
+ PORTS_PER_OCMB = 1,
DIMMS_PER_PORT = 2,
};
};
@@ -343,16 +346,17 @@ enum class throttle_type
};
///
-/// @brief Trait classes for proc_type
+/// @brief Trait classes for mc_type
+/// @tparam MC the mc_type
///
@@ -343,16 +346,17 @@ enum class throttle_type
///
-/// @brief Trait classes for proc_type - NIMBUS specialization
+/// @brief Trait classes for mc_type - NIMBUS specialization
///
template< >
@@ -368,15 +372,19 @@ struct procTraits<proc_type::NIMBUS>
};
///
-/// @brief Trait classes for proc_type - AXONE specialization
+/// @brief Trait classes for mc_type - EXPLORER specialization
///
OpenPOWER on IntegriCloud